@@ -17,11 +17,15 @@ class PatchReviewBehaviour(vcsreview.PatchReviewBehaviour):
     """
     def reviewers_rset(self):
         rset = self._cw.execute(
-            'DISTINCT Any U, "" '
-            'WHERE P eid %(p)s, '
-            '      P patch_ticket T, '
-            '      PS patch_ticket T, '
-            '      PS patch_reviewer U',
+            'DISTINCT Any U, NULL '
+            'WHERE P eid %(p)s,'
+            '      P patch_ticket T,'
+            '      PS patch_ticket T,'
+            '      PS patch_reviewer U,'
+            '      P patch_revision RE,'
+            '      RE from_repository R,'
+            '      EXISTS(R use_global_groups TRUE, U in_group G, G name "reviewers")'
+            '      OR EXISTS(R repository_reviewer U)',
             {'p': self.entity.eid})
         if not rset:
             rset = super(PatchReviewBehaviour, self).reviewers_rset()
