@@ -23,9 +23,10 @@ def registration_callback(vreg):
             if not patch:
                 return super(TaskAddedView, self).subject()
             if patch.__regid__ == 'InsertionPoint':
-                patch = patch.parent.patch
+                patch = patch.parent.reverse_patch_revision
                 if not patch:
                     return super(TaskAddedView, self).subject()
+                patch = patch[0]
             if patch.repository.project:
                 repo_title = patch.repository.project.dc_title()
             else:
